@@ -1,7 +1,5 @@
 """Standalone script to detokenize a corpus."""
 
-from __future__ import print_function
-
 import argparse
 
 from opennmt import tokenizers
@@ -12,10 +10,12 @@ def main():
   parser.add_argument(
       "--delimiter", default=" ",
       help="Token delimiter used in text serialization.")
-  tokenizers.add_command_line_arguments(parser)
+  parser.add_argument(
+      "--tokenizer_config", default=None,
+      help="Tokenization configuration.")
   args = parser.parse_args()
 
-  tokenizer = tokenizers.build_tokenizer(args)
+  tokenizer = tokenizers.make_tokenizer(args.tokenizer_config)
   tokenizer.detokenize_stream(delimiter=args.delimiter)
 
 if __name__ == "__main__":
